@@ -535,8 +535,9 @@ class CGATS(dict):
                                 else display
                             )
                     if display:
-                        tech += " (%s)" % display
-                desc = tech.encode("utf-8")  # TODO: This could be problematic
+                        tech += f" ({display})"
+                if isinstance(tech, str):
+                    desc = tech.encode("utf-8")
         if not desc and self.filename:
             # With Python 3.6+ the encoding is always "utf-8" independent of the OS.
             desc = bytes(
@@ -617,7 +618,10 @@ class CGATS(dict):
                 elif isinstance(value, (float, int, bytes)):
                     if key not in ("NUMBER_OF_FIELDS", "NUMBER_OF_SETS"):
                         if isinstance(key, int):
-                            result.append(bytes(str(value), "utf-8"))
+                            if isinstance(value, bytes):
+                                result.append(value)
+                            else:
+                                result.append(bytes(str(value), "utf-8"))
                         else:
                             if "KEYWORDS" in self and key in list(
                                 self["KEYWORDS"].values()
