@@ -21,14 +21,14 @@ uninstall (setup.py uninstall --record=INSTALLED_FILES), otherwise use
 the wrapper script in the root directory of the source tar.gz/zip
 
 """
-import functools
-from configparser import ConfigParser
-from distutils.command.install import install
-from distutils.util import change_root, get_platform
-from fnmatch import fnmatch
 import codecs
 import ctypes.util
+from configparser import ConfigParser
+from distutils.command.install import install
 import distutils.core
+from distutils.util import change_root, get_platform
+from fnmatch import fnmatch
+import functools
 import os
 import platform
 import re
@@ -38,7 +38,7 @@ import sys
 from time import strftime
 
 
-# # Borrowed from setuptools
+# Borrowed from setuptools
 def _find_all_simple(path):
     """
     Find all files under 'path'
@@ -64,25 +64,27 @@ def findall(dir=os.curdir):
 
 
 import distutils.filelist
+
 distutils.filelist.findall = findall  # Fix findall bug in distutils
 
 
 from DisplayCAL.defaultpaths import autostart, autostart_home
 from DisplayCAL.meta import (
+    appstream_id,
     author,
     author_ascii,
+    author_email,
     description,
-    longdesc,
+    development_home_page,
     DOMAIN,
+    longdesc,
     name,
     py_maxversion,
     py_minversion,
+    script2pywname,
     version,
     version_tuple,
     wx_minversion,
-    author_email,
-    script2pywname,
-    appstream_id,
 )
 from DisplayCAL.util_list import intlist
 from DisplayCAL.util_os import getenvu, relpath, safe_glob
@@ -188,7 +190,7 @@ config = {
             "xrc/*.xrc",
         ]
     },
-    "xtra_package_data": {name: {"win32": ["theme/icons/%s-uninstall.ico" % name]}},
+    "xtra_package_data": {name: {"win32": [f"theme/icons/{name}-uninstall.ico"]}},
 }
 
 
@@ -197,15 +199,16 @@ def add_lib_excludes(key, excludebits):
         config["excludes"][key].extend([f"{name}.lib{exclude}", f"lib{exclude}"])
 
     for exclude in ("32", "64"):
-        for pycompat in ("38", "39", "310", "311"):
+        for pycompat in ("38", "39", "310", "311", "312", "313"):
             if key == "win32" and (
-                pycompat == str(sys.version_info[0]) + str(sys.version_info[1]) or exclude == excludebits[0]
+                pycompat == str(sys.version_info[0]) + str(sys.version_info[1])
+                or exclude == excludebits[0]
             ):
                 continue
             config["excludes"][key].extend(
                 [
-                    name + ".lib%s.python%s" % (exclude, pycompat),
-                    name + ".lib%s.python%s.RealDisplaySizeMM" % (exclude, pycompat),
+                    f"{name}.lib{exclude}.python{pycompat}",
+                    f"{name}.lib{exclude}.python{pycompat}.RealDisplaySizeMM",
                 ]
             )
 
@@ -233,7 +236,7 @@ plist_dict = {
     "CFBundleShortVersionString": version,
     "CFBundleSignature": "????",
     "CFBundleVersion": ".".join(map(str, version_tuple)),
-    "NSHumanReadableCopyright": "© %s %s" % (strftime("%Y"), author),
+    "NSHumanReadableCopyright": f"© {strftime('%Y')} {author}",
     "LSMinimumSystemVersion": "10.6.0",
 }
 
@@ -310,14 +313,14 @@ def create_app_symlinks(dist_dir, scripts):
                         # py2app
                         with open(src, "r") as main_in:
                             py = main_in.read()
-                        py = py.replace("main()", "main(%r)" % script[len(name) + 1:])
+                        py = py.replace("main()", "main(%r)" % script[len(name) + 1 :])
                         with open(tgt, "wb") as main_out:
                             main_out.write(py.encode())
                         continue
                     if subentry == name + ".icns":
                         shutil.copy(
-                            os.path.join(pydir, "theme", "icons", "%s.icns" % script),
-                            os.path.join(toolcontents, entry, "%s.icns" % script),
+                            os.path.join(pydir, "theme", "icons", f"{script}.icns"),
+                            os.path.join(toolcontents, entry, f"{script}.icns"),
                         )
                         continue
                     if subentry == script:
@@ -342,12 +345,10 @@ def create_app_symlinks(dist_dir, scripts):
                     infoxml,
                 )
                 # CFBundleIdentifier
-                infoxml = infoxml.replace(
-                    ".%s</string>" % name, ".%s</string>" % script
-                )
+                infoxml = infoxml.replace(f".{name}</string>", f".{script}</string>")
                 # CFBundleIconFile
                 infoxml = infoxml.replace(
-                    "%s.icns</string>" % name, "%s.icns</string>" % script
+                    f"{name}.icns</string>", f"{script}.icns</string>"
                 )
                 # CFBundleExecutable
                 infoxml = re.sub(
@@ -367,12 +368,24 @@ def create_app_symlinks(dist_dir, scripts):
 
 
 def get_data(tgt_dir, key, pkgname=None, subkey=None, excludes=None):
-    """Return configured data files"""
+    """Return configured data files.
+
+    Args:
+        tgt_dir (str): The target directory.
+        key (str): The config key.
+        pkgname (Union[None, str]): Name of the package. Default is None.
+        subkey (Union[None, str]): Name of the subkey. Default is None.
+        excludes (Union[None, List[str]]): List of files to exclude. Default is None.
+
+    Returns:
+        List[str]: List of strings showing the paths of the data files.
+    """
     files = config[key]
     src_dir = source_dir
     if pkgname:
         files = files[pkgname]
-        src_dir = os.path.join(src_dir, pkgname)
+        # modifying the src_dir is not working with py2app, so disabling it.
+        # src_dir = os.path.join(src_dir, pkgname)
         if subkey:
             if subkey in files:
                 files = files[subkey]
@@ -381,12 +394,19 @@ def get_data(tgt_dir, key, pkgname=None, subkey=None, excludes=None):
     data = []
     for pth in files:
         if not [exclude for exclude in excludes or [] if fnmatch(pth, exclude)]:
-            data.append(
-                (
-                    os.path.normpath(os.path.join(tgt_dir, os.path.dirname(pth))),
-                    safe_glob(os.path.join(src_dir, pth)),
-                )
+            normalized_path = os.path.normpath(
+                os.path.join(tgt_dir, os.path.dirname(pth))
             )
+            safe_path = [
+                relpath(p, src_dir) for p in safe_glob(os.path.join(src_dir, pth))
+            ]
+            if pkgname:
+                # try looking for the "{src_dir}/{pkgname}/{pth}" too
+                safe_path += [
+                    relpath(p, src_dir)
+                    for p in safe_glob(os.path.join(src_dir, pkgname, pth))
+                ]
+            data.append((normalized_path, safe_path))
     return data
 
 
@@ -411,9 +431,8 @@ def get_scripts(excludes=None):
         script = os.path.basename(script)
         if script == appname.lower() + "-apply-profiles-launcher":
             continue
-        desktopfile = os.path.join(pydir, "..", "misc", script + ".desktop")
+        desktopfile = os.path.join(pydir, "..", "misc", f"{script}.desktop")
         if os.path.isfile(desktopfile):
-            print("desktopfile: %s" % desktopfile)
             cfg = ConfigParser()
             cfg.read(desktopfile)
             script = cfg.get("Desktop Entry", "Exec").split()[0]
@@ -470,12 +489,6 @@ def setup():
     if use_setuptools:
         if "--use-setuptools" in sys.argv[1:] and not os.path.exists("use-setuptools"):
             open("use-setuptools", "w").close()
-        try:
-            from ez_setup import use_setuptools as ez_use_setuptools
-
-            ez_use_setuptools()
-        except ImportError:
-            pass
         try:
             import setuptools
             from setuptools import setup, Extension, find_packages
@@ -519,27 +532,30 @@ def setup():
 
     if do_uninstall:
         i = sys.argv.index("uninstall")
-        sys.argv = sys.argv[:i] + ["install"] + sys.argv[i + 1:]
+        sys.argv = sys.argv[:i] + ["install"] + sys.argv[i + 1 :]
         install.create_home_path = lambda self: None
 
-    if skip_instrument_conf_files := "--skip-instrument-configuration-files" in sys.argv[1:]:
+    if (
+        skip_instrument_conf_files := "--skip-instrument-configuration-files"
+        in sys.argv[1:]
+    ):
         i = sys.argv.index("--skip-instrument-configuration-files")
-        sys.argv = sys.argv[:i] + sys.argv[i + 1:]
+        sys.argv = sys.argv[:i] + sys.argv[i + 1 :]
 
     if not is_rpm_build:
         skip_instrument_conf_files = True
 
     if skip_postinstall:
         i = sys.argv.index("--skip-postinstall")
-        sys.argv = sys.argv[:i] + sys.argv[i + 1:]
+        sys.argv = sys.argv[:i] + sys.argv[i + 1 :]
 
     if "--use-distutils" in sys.argv[1:]:
         i = sys.argv.index("--use-distutils")
-        sys.argv = sys.argv[:i] + sys.argv[i + 1:]
+        sys.argv = sys.argv[:i] + sys.argv[i + 1 :]
 
     if "--use-setuptools" in sys.argv[1:]:
         i = sys.argv.index("--use-setuptools")
-        sys.argv = sys.argv[:i] + sys.argv[i + 1:]
+        sys.argv = sys.argv[:i] + sys.argv[i + 1 :]
 
     argv = list(sys.argv[1:])
     for i, arg in enumerate(reversed(argv)):
@@ -560,13 +576,13 @@ def setup():
             arg = arg.split("=")
             if arg[0] == "--debug":
                 debug = 1 if len(arg) == 1 else int(arg[1])
-                sys.argv = sys.argv[:n] + sys.argv[n + 1:]
+                sys.argv = sys.argv[:n] + sys.argv[n + 1 :]
             elif len(arg) == 2:
                 if arg[0] == "--dist-dir":
                     dist_dir = arg[1]
                 elif arg[0] == "--doc-layout":
                     doc_layout = arg[1]
-                    sys.argv = sys.argv[:n] + sys.argv[n + 1:]
+                    sys.argv = sys.argv[:n] + sys.argv[n + 1 :]
                 elif arg[0] == "--install-data":
                     install_data = arg[1]
                 elif arg[0] == "--prefix":
@@ -613,9 +629,11 @@ def setup():
     # on Mac OS X and Windows, we want data files in the package dir
     # (package_data will be ignored when using py2exe)
     package_data = {
-        name: config["package_data"][name]
-        if sys.platform in ("darwin", "win32") and not do_py2app and not do_py2exe
-        else []
+        name: (
+            config["package_data"][name]
+            if sys.platform in ("darwin", "win32") and not do_py2app and not do_py2exe
+            else []
+        )
     }
     if sdist and sys.platform in ("darwin", "win32"):
         package_data[name].extend(
@@ -642,7 +660,25 @@ def setup():
                 )
             )
         else:
-            data_files.append((doc, [os.path.join(pydir, "..", "LICENSE.txt")]))
+            data_files.append(
+                (doc, [relpath(os.path.join(pydir, "..", "LICENSE.txt"), source_dir)])
+            )
+
+    # metainfo / appdata.xml
+    data_files.append(
+        (
+            os.path.join(os.path.dirname(data), "metainfo"),
+            [
+                relpath(
+                    os.path.normpath(
+                        os.path.join(pydir, "..", "dist", f"{appstream_id}.appdata.xml")
+                    ),
+                    source_dir,
+                )
+            ],
+        )
+    )
+
     if sys.platform not in ("darwin", "win32") or do_py2app or do_py2exe:
         # Linux/Unix or py2app/py2exe
         data_files += get_data(data, "package_data", name, excludes=["theme/icons/*"])
@@ -692,12 +728,6 @@ def setup():
                     print("WARNING: OpenAL32.dll not found!")
         elif sys.platform != "darwin":
             # Linux
-            data_files.append(
-                (
-                    os.path.join(os.path.dirname(data), "metainfo"),
-                    [os.path.join(pydir, "..", "dist", appstream_id + ".appdata.xml")],
-                )
-            )
             data_files.append(
                 (
                     os.path.join(os.path.dirname(data), "applications"),
@@ -709,9 +739,11 @@ def setup():
             )
             data_files.append(
                 (
-                    autostart
-                    if os.geteuid() == 0 or prefix.startswith("/")
-                    else autostart_home,
+                    (
+                        autostart
+                        if os.geteuid() == 0 or prefix.startswith("/")
+                        else autostart_home
+                    ),
                     [
                         os.path.join(
                             pydir,
@@ -911,7 +943,8 @@ def setup():
 from distutils.core import setup, Extension
 
 setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sources}, define_macros={macros}, extra_link_args={link_args})])""",
-                    ] + sys.argv[1:],
+                    ]
+                    + sys.argv[1:],
                     stdout=sp.PIPE,
                     stderr=sp.STDOUT,
                 )
@@ -948,20 +981,17 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
     if not setuptools or sys.platform != "win32":
         # wxPython windows installer doesn't add egg-info entry, so
         # a dependency check from pkg_resources would always fail
-        requires.append("wxPython (>= %s)" % ".".join(str(n) for n in wx_minversion))
+        requires.append(
+            "wxPython (>= {})".format(".".join(str(n) for n in wx_minversion))
+        )
     if sys.platform == "win32":
         requires.append("pywin32 (>= 213.0)")
 
     packages = [name, f"{name}.lib", f"{name}.lib.agw"]
     if sdist:
         # For source distributions we want all libraries
-        for pycompat in ("38", "39", "310", "311"):
-            packages.extend(
-                [
-                    f"{name}.lib{bits}",
-                    f"{name}.lib{bits}.python{pycompat}"
-                ]
-            )
+        for pycompat in ("38", "39", "310", "311", "312", "313"):
+            packages.extend([f"{name}.lib{bits}", f"{name}.lib{bits}.python{pycompat}"])
     elif sys.platform == "darwin":
         # On Mac OS X we only want the universal binaries
         packages.append(f"{name}.lib{bits}")
@@ -991,11 +1021,14 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
             "Programming Language :: Python :: 3.8",
             "Programming Language :: Python :: 3.9",
             "Programming Language :: Python :: 3.10",
+            "Programming Language :: Python :: 3.11",
+            "Programming Language :: Python :: 3.12",
+            "Programming Language :: Python :: 3.13",
             "Topic :: Multimedia :: Graphics",
         ],
         "data_files": data_files,
         "description": description,
-        "download_url": f"https://{DOMAIN}/download/{name}-{version}.tar.gz",
+        "download_url": f"{development_home_page}/releases/download/{version}/{name}-{version}.tar.gz",
         "ext_modules": ext_modules,
         "license": "GPL v3",
         "long_description": longdesc,
@@ -1005,8 +1038,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
         "package_data": package_data,
         "package_dir": {name: name},
         "platforms": [
-            "Python >= %s <= %s"
-            % (
+            "Python >= {} <= {}".format(
                 ".".join(str(n) for n in py_minversion),
                 ".".join(str(n) for n in py_maxversion),
             ),
@@ -1024,13 +1056,14 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
     if setuptools:
         attrs["entry_points"] = {
             "gui_scripts": [
-                "%s = %s.main:main%s"
-                % (
+                "{} = {}.main:main{}".format(
                     script,
                     name,
-                    ""
-                    if script == name.lower()
-                    else script[len(name):].lower().replace("-", "_"),
+                    (
+                        ""
+                        if script == name.lower()
+                        else script[len(name) :].lower().replace("-", "_")
+                    ),
                 )
                 for script, desc in scripts
             ]
@@ -1068,7 +1101,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
             pydir,
             "..",
             "dist",
-            f"py2app.{get_platform()}-py{sys.version[:3]}",
+            f"py2app.{get_platform()}-py{sys.version_info[0]}.{sys.version_info[1]}",
             f"{name}-{version}",
         )
         from py2app.build_app import py2app as py2app_cls
@@ -1083,7 +1116,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
         py2app_cls.copy_package_data = copy_package_data
         attrs["options"] = {
             "py2app": {
-                "argv_emulation": True,
+                "argv_emulation": False,
                 "dist_dir": dist_dir,
                 "excludes": config["excludes"]["all"] + config["excludes"]["darwin"],
                 "iconfile": os.path.join(pydir, "theme", "icons", f"{name}.icns"),
@@ -1110,7 +1143,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
                 "misc",
                 name
                 + (
-                    ".exe.%s.VC90.manifest" % arch
+                    f".exe.{arch}.VC90.manifest"
                     if hasattr(sys, "version_info") and sys.version_info[:2] >= (3, 8)
                     else ".exe.manifest"
                 ),
@@ -1120,8 +1153,8 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
         if not os.path.isdir(tmp_scripts_dir):
             os.makedirs(tmp_scripts_dir)
         apply_profiles_launcher = (
-            appname.lower() + "-apply-profiles-launcher",
-            appname + " Profile Loader Launcher",
+            f"{appname.lower()}-apply-profiles-launcher",
+            f"{appname} Profile Loader Launcher",
         )
         for script, desc in scripts + [apply_profiles_launcher]:
             shutil.copy(
@@ -1144,7 +1177,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
                         )
                     ],
                     "other_resources": [(24, 1, manifest_xml)],
-                    "copyright": "© %s %s" % (strftime("%Y"), author),
+                    "copyright": f"© {strftime('%Y')} {author}",
                     "description": desc,
                 }
             )
@@ -1175,7 +1208,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
                         )
                     ],
                     "other_resources": [(24, 1, manifest_xml)],
-                    "copyright": "© %s %s" % (strftime("%Y"), author),
+                    "copyright": f"© {strftime('%Y')} {author}",
                     "description": apply_profiles_launcher[1],
                 }
             )
@@ -1212,7 +1245,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
                         )
                     ],
                     "other_resources": [(24, 1, manifest_xml)],
-                    "copyright": "© %s %s" % (strftime("%Y"), author),
+                    "copyright": f"© {strftime('%Y')} {author}",
                     "description": desc,
                 }
             )
@@ -1239,7 +1272,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
                         )
                     ],
                     "other_resources": [(24, 1, manifest_xml)],
-                    "copyright": "© %s %s" % (strftime("%Y"), author),
+                    "copyright": f"© {strftime('%Y')} {author}",
                     "description": "Convert eeColor 65^3 to madVR 256^3 3D LUT "
                     "(video levels in, video levels out)",
                 }
@@ -1250,7 +1283,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
             pydir,
             "..",
             "dist",
-            f"py2exe.{get_platform()}-py{sys.version[:3]}",
+            f"py2exe.{get_platform()}-py{sys.version_info[0]}.{sys.version_info[1]}",
             f"{name}-{version}",
         )
         attrs["options"] = {
@@ -1271,7 +1304,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
                 "excludes": config["excludes"]["all"] + config["excludes"]["win32"],
                 "bundle_files": 3 if wx.VERSION >= (2, 8, 10, 1) else 1,
                 "compressed": 1,
-                "optimize": 0  # 0 = don’t optimize (generate .pyc)
+                "optimize": 0,  # 0 = don’t optimize (generate .pyc)
                 # 1 = normal optimization (like python -O)
                 # 2 = extra optimization (like python -OO)
             }
@@ -1399,8 +1432,12 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
                     # setuptools
                     paths += (
                         safe_glob(path)
-                        + safe_glob(f"{path}-{version}-py{sys.version[:3]}*.egg")
-                        + safe_glob(f"{path}-{version}-py{sys.version[:3]}*.egg-info")
+                        + safe_glob(
+                            f"{path}-{version}-py{sys.version_info[0]}.{sys.version_info[1]}*.egg"
+                        )
+                        + safe_glob(
+                            f"{path}-{version}-py{sys.version_info[0]}.{sys.version_info[1]}*.egg-info"
+                        )
                     )
 
             if os.path.isabs(data) and data not in paths:
@@ -1545,8 +1582,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
         for _datadir, datafiles in attrs.get("data_files", []):
             for datafile in datafiles:
                 manifest_in.append(
-                    "include "
-                    + (
+                    "include {}".format(
                         relpath(os.path.sep.join(datafile.split("/")), source_dir)
                         or datafile
                     )
@@ -1568,13 +1604,16 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
                     "include " + os.path.sep.join([pkgdir] + obj.split("/"))
                 )
         for pymod in attrs.get("py_modules", []):
-            manifest_in.append("include " + os.path.join(*pymod.split(".")))
-        manifest_in.append("include " + os.path.join(name, "theme", "theme-info.txt"))
+            manifest_in.append("include {}".format(os.path.join(*pymod.split("."))))
         manifest_in.append(
-            "recursive-include %s %s %s"
-            % (os.path.join(name, "theme", "icons"), "*.icns", "*.ico")
+            "include {}".format(os.path.join(name, "theme", "theme-info.txt"))
         )
-        manifest_in.append("include " + os.path.join("man", "*.1"))
+        manifest_in.append(
+            "recursive-include {} {} {}".format(
+                os.path.join(name, "theme", "icons"), "*.icns", "*.ico"
+            )
+        )
+        manifest_in.append("include {}".format(os.path.join("man", "*.1")))
         manifest_in.append("recursive-include misc *")
         if skip_instrument_conf_files:
             manifest_in.extend(
@@ -1584,9 +1623,9 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
                     "exclude misc/*.usermap",
                 ]
             )
-        manifest_in.append("include " + os.path.join("screenshots", "*.png"))
-        manifest_in.append("include " + os.path.join("scripts", "*"))
-        manifest_in.append("include " + os.path.join("tests", "*"))
+        manifest_in.append("include {}".format(os.path.join("screenshots", "*.png")))
+        manifest_in.append("include {}".format(os.path.join("scripts", "*")))
+        manifest_in.append("include {}".format(os.path.join("tests", "*")))
         manifest_in.append("recursive-include theme *")
         manifest_in.append("recursive-include util *.cmd *.py *.sh")
         if sys.platform == "win32" and not setuptools:
@@ -1604,12 +1643,12 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
 
         if bdist_bbfreeze:
             i = sys.argv.index("bdist_bbfreeze")
-            if "-d" not in sys.argv[i + 1:] and "--dist-dir" not in sys.argv[i + 1:]:
+            if "-d" not in sys.argv[i + 1 :] and "--dist-dir" not in sys.argv[i + 1 :]:
                 dist_dir = os.path.join(
                     pydir,
                     "..",
                     "dist",
-                    "bbfreeze.%s-py%s" % (get_platform(), sys.version[:3]),
+                    f"bbfreeze.{get_platform()}-py{sys.version_info[0]}.{sys.version_info[1]}",
                 )
                 sys.argv.insert(i + 1, f"--dist-dir={dist_dir}")
             if "egg_info" not in sys.argv[1:i]:
@@ -1643,10 +1682,12 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
         if do_py2exe:
             shutil.copy(
                 os.path.join(
-                    dist_dir, "python%s.dll" % (sys.version[0] + sys.version[2])
+                    dist_dir, f"python{sys.version_info[0]}{sys.version_info[1]}.dll"
                 ),
                 os.path.join(
-                    dist_dir, "lib", "python%s.dll" % (sys.version[0] + sys.version[2])
+                    dist_dir,
+                    "lib",
+                    f"python{sys.version_info[0]}{sys.version_info[1]}.dll",
                 ),
             )
 
@@ -1686,6 +1727,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
 
 def setup_do_py2exe():
     import py2exe
+
     # ModuleFinder can't handle runtime changes to __path__, but win32com
     # uses them
     try:
@@ -1717,20 +1759,6 @@ def setup_do_py2exe():
 
     py2exe.build_exe.isSystemDLL = isSystemDLL
 
-    # Numpy DLL paths fix
-    def numpy_dll_paths_fix():
-        import numpy
-
-        paths = set()
-        numpy_path = numpy.__path__[0]
-        for dirpath, dirnames, filenames in os.walk(numpy_path):
-            for item in filenames:
-                if item.lower().endswith(".dll"):
-                    paths.add(dirpath)
-        sys.path.extend(paths)
-
-    numpy_dll_paths_fix()
-
 
 if __name__ == "__main__":
     setup()
